.. pyfreekassa documentation master file, created by
   sphinx-quickstart on Mon Jan  9 14:38:40 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyfreekassa's documentation!
=======================================



.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Nonce
   OrderID
   Currencies
   Configuration
   FreekassaApi


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
